/*
 * Cantata
 *
 * Copyright (c) 2017 Craig Drummond <craig.p.drummond@gmail.com>
 *
 * ----
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifndef STATS_DB_H
#define STATS_DB_H

#include <QString>
#include <QStringList>
#include <QQueue>
#include <QObject>
#include <QUrl>
#include <QMap>
#include <time.h>
#include "mpd-interface/mpdstatus.h"
#include "mpd-interface/song.h"

class PausableTimer;
struct MPDStatusValues;

class StatsDb : public QObject
{
	Q_OBJECT
public:
    static StatsDb * self();
    static void enableDebug();

    StatsDb();
    ~StatsDb();

private Q_SLOTS:
    void setSong(const Song &s);
    void commitCurrent();
    void mpdStateUpdated(bool songChanged=false);
    void mpdStatusUpdated(const MPDStatusValues &vals);

private:
    void setActive();
    void loadSettings();
    void calcCommitTime();

private:
    bool enabled;
    Song inactiveSong; // Song set whilst inactive
    Song currentSong;
    PausableTimer * commitTimer;
    bool commitedCurrent;
    MPDState lastState;
};

#endif
